@@ -11,6 +11,9 @@ class WibuAPI:
         self.deprecated_url = "https://api.wibu-api.eu.org/api"
 
     def lendrive(self, link: str):
+        """works with batch, bd, and single eps link
+        https://lendrive.web.id/tondemo-skill-de-isekai-hourou-meshi-ep-04-dual-subs-x265-hevc-subtitle-indonesia-english/
+        """
         try:
             url = f"{self.base_url}/anime/lendrive?link={link}"
             response = get(url, timeout=15).json()
@@ -18,7 +21,18 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
-    """
+    def donghua(self, link: str):
+        """works with batch, bd, and single eps link
+        https://donghua.web.id/soul-land-season-2-episode-224-250
+        """
+        try:
+            url = f"{self.base_url}/anime/donghua?link={link}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
+    """ off, due to cloudflare v2 captcha
     def anichin(self, link: str):
         try:
             url = f"{self.base_url}/anime/anichin?link={link}"
@@ -29,6 +43,9 @@ class WibuAPI:
     """
 
     def kusonime(self, link: str):
+        """works with batch, bd, and single eps link
+        https://kusonime.com/isekai-ojisan-batch-subtitle-indonesia/
+        """
         try:
             url = f"{self.base_url}/anime/kusonime?link={link}"
             response = get(url, timeout=15).json()
@@ -37,6 +54,9 @@ class WibuAPI:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
     def doronime(self, link: str):
+        """works with batch, bd, and single eps link
+        https://doronime.id/anime/om-ke-isekai/batch
+        """
         try:
             url = f"{self.base_url}/anime/doronime?link={link}"
             response = get(url, timeout=15).json()
@@ -45,6 +65,10 @@ class WibuAPI:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
     def rawkuma(self, link: str):
+        """works with list and single chapter
+        list: https://rawkuma.com/manga/guilty-circle/
+        single: https://rawkuma.com/guilty-circle-chapter-83/
+        """
         try:
             url = f"{self.base_url}/manga/rawkuma?link={link}"
             response = get(url, timeout=15).json()
@@ -53,6 +77,10 @@ class WibuAPI:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
     def westmanga(self, link: str):
+        """works with list and single chapter
+        list: https://westmanga.info/manga/kaifuku-jutsushi-no-yarinaoshi/
+        single: https://westmanga.info/kaifuku-jutsushi-no-yarinaoshi-chapter-52-1-bahasa-indonesia/
+        """
         try:
             url = f"{self.base_url}/manga/westmanga?link={link}"
             response = get(url, timeout=15).json()
@@ -60,7 +88,23 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
+    def komikindo(self, link: str):
+        """work with list and single chapter
+        list: https://komikindo.co/manga/yuusha-ni-zenbu-ubawareta-ore-wa-yuusha-no-hahaoya-to-party-wo-kumimashita/
+        single: https://komikindo.co/yuusha-ni-zenbu-ubawareta-ore-wa-yuusha-no-hahaoya-to-party-wo-kumimashita-chapter-04/
+        """
+        try:
+            url = f"{self.base_url}/manga/komikindo?link={link}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
     def doujindesu(self, link: str):
+        """works with list and single chapter
+        list: https://212.32.226.234/manga/i-cant-stand-it-ajumma/
+        single: https://212.32.226.234/i-cant-stand-it-ajumma-chapter-20/
+        """
         try:
             url = f"{self.base_url}/manga/doudesu?link={link}"
             response = get(url, timeout=15).json()
@@ -69,6 +113,9 @@ class WibuAPI:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
     def wibusubs(self, link: str):
+        """work with single post link (may bug sometimes)
+        https://www.wibusubs.moe/2023/03/brother-trap-2023-09-tamat-subtitle.html
+        """
         try:
             url = f"{self.base_url}/drama/wibusubs?link={link}"
             response = get(url, timeout=5).json()
@@ -138,6 +185,9 @@ class WibuAPI:
 
     def brawlClub(self, tag: str):
         try:
+            if "#" not in tag:
+                tag = f"%23{tag}"
+            tag = tag.replace("#", "%23")
             url = f"{self.deprecated_url}/game/brawl/club?clubTag={tag}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
@@ -146,6 +196,9 @@ class WibuAPI:
 
     def brawlClubMember(self, tag: str):
         try:
+            if "#" not in tag:
+                tag = f"%23{tag}"
+            tag = tag.replace("#", "%23")
             url = f"{self.deprecated_url}/game/brawl/club/member?clubTag={tag}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
@@ -162,6 +215,9 @@ class WibuAPI:
 
     def brawlPlayer(self, tag: str):
         try:
+            if "#" not in tag:
+                tag = f"%23{tag}"
+            tag = tag.replace("#", "%23")
             url = f"{self.deprecated_url}/game/brawl/player?playerTag={tag}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
@@ -170,6 +226,9 @@ class WibuAPI:
 
     def brawlPlayerLog(self, tag: str):
         try:
+            if "#" not in tag:
+                tag = f"%23{tag}"
+            tag = tag.replace("#", "%23")
             url = f"{self.deprecated_url}/game/brawl/player/log?playerTag={tag}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
@@ -209,8 +268,11 @@ class WibuAPI:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
     def youtube(self, url: str):
+        """tested on youtube video link, other not tested yet
+        https://www.youtube.com/watch?v=a1V0UbBNliM
+        """
         try:
-            url = f"{self.base_url}/etc/youtube?query={url}"
+            url = f"{self.base_url}/etc/youtube?url={url}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
         except Exception as e:
